@@ -19,8 +19,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program; if not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <gnumeric-config.h>
@@ -431,6 +430,7 @@ extract_settings (SolverState *state)
 	GET_BOOL_ENTRY ("non_neg_button", options.assume_non_negative);
 	GET_BOOL_ENTRY ("all_int_button", options.assume_discrete);
 	GET_BOOL_ENTRY ("program", options.program_report);
+	GET_BOOL_ENTRY ("sensitivity", options.sensitivity_report);
 
 	g_free (param->options.scenario_name);
 	param->options.scenario_name = g_strdup
@@ -569,7 +569,7 @@ update_obj_value (SolverState *state)
 						 r->value);
 	} else {
 		valtxt = NULL;
-		txt = g_strdup ("");
+		txt = "";
 	}
 
 	gtk_label_set_text (GTK_LABEL (state->run.objective_value_widget),
@@ -682,7 +682,7 @@ static void
 create_report (GnmSolver *sol, SolverState *state)
 {
 	Sheet *sheet = state->sheet;
-	char *base = g_strdup_printf ("%s Report", sheet->name_unquoted);
+	char *base = g_strdup_printf (_("%s %%s Report"), sheet->name_unquoted);
 	gnm_solver_create_report (sol, base);
 	g_free (base);
 }
@@ -769,14 +769,11 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 		gnm_solver_store_result (sol);
 		redo = clipboard_copy_range_undo (sr.sheet, &sr.range);
 
-		if (param->options.program_report) {
+		if (param->options.program_report ||
+		    param->options.sensitivity_report) {
 			Workbook *wb = param->sheet->workbook;
 			GOUndo *undo_report, *redo_report;
 
-			/* This is a bit of overkill -- it just removes the
-			   sheet that create_report will add.  However, if
-			   in the future we add multiple sheets then this
-			   should still be good.  */
 			undo_report = go_undo_binary_new
 				(wb,
 				 workbook_sheet_state_new (wb),
@@ -1147,6 +1144,7 @@ dialog_init (SolverState *state)
 	INIT_BOOL_ENTRY ("non_neg_button", options.assume_non_negative);
 	INIT_BOOL_ENTRY ("all_int_button", options.assume_discrete);
 	INIT_BOOL_ENTRY ("program", options.program_report);
+	INIT_BOOL_ENTRY ("sensitivity", options.sensitivity_report);
 
 	input = gnm_solver_param_get_input (param);
 	if (input != NULL)
